#! /usr/bin/python3

import os, os.path
import sqlite3

class Contacts:
    def __init__(self, jolla=os.getenv("HOME")):
        dbfile = os.path.join(jolla, ".local/share/system/Contacts/qtcontacts-sqlite/contacts.db")
        self._db = sqlite3.connect(dbfile)
    
    def list(self, filter=None):
        cursor = self._db.cursor()
        
        query = """
SELECT Contacts.displayLabel, Contacts.firstName, Contacts.lastName,
       PhoneNumbers.phoneNumber, PhoneNumbers.subTypes
FROM Contacts, PhoneNumbers
WHERE PhoneNumbers.contactId = Contacts.contactId
        """
        
        if filter is None:
            results = cursor.execute(query)
        else:
            query  += "AND Contacts.displayLabel LIKE ?"
            results = cursor.execute(query, ["%" + filter + "%"])
        
        for (_, first, last, phonenumber, phonetype) in results:
            c = {}
            c["last"]        = last
            c["first"]       = first
            c["phonenumber"] = phonenumber
            
            yield c

    def by_number(self, number):
        cursor = self._db.cursor()
        
        query = """
SELECT Contacts.displayLabel, Contacts.firstName, Contacts.lastName,
       PhoneNumbers.phoneNumber, PhoneNumbers.subTypes
FROM  Contacts, PhoneNumbers
WHERE PhoneNumbers.contactId = Contacts.contactId
AND   PhoneNumbers.phoneNumber = ?
        """
        
        results = cursor.execute(query, [number])
        
        for (displayLabel, first, last, phonenumber, phonetype) in results:
            c = {}
            c["displayLabel"] = displayLabel
            c["last"]         = last
            c["first"]        = first
            c["phonenumber"]  = phonenumber
            
            yield c
        
